pub fn runtime_concurrent<R, S, E>(
handler: S,
) -> Runtime<impl Service<LambdaInvocation, Response = (), Error = Error, Future: Send> + Clone + Send + 'static>Available on crate feature
concurrency-tokio only.Expand description
Returns a configured Runtime wrapping the given
handler for concurrent execution, without starting the event loop.
This is the concurrent variant of runtime(). Use it when you need SnapStart
hooks AND your handler supports concurrent invocations.
Panics
This function panics if required Lambda environment variables are missing.